@@ -11,11 +11,12 @@ SERVICE_URL = "https://logs.qwhale.ml/"
 
 
 class QWhaleLogsHandler(Handler):
-    def __init__(self, token: str, batch_site: int = 100):
+    def __init__(self, token: str, batch_site: int = 100, timeout: float = 7.5):
         self.token = token
         self.logs = []
         self.batch = None
         self.batch_size = batch_site
+        self.timeout = timeout
         self.executor = ThreadPoolExecutor(max_workers=5)
         super().__init__()
 
@@ -25,7 +26,8 @@ class QWhaleLogsHandler(Handler):
             requests.put(
                 urljoin(SERVICE_URL, "/api/logs"),
                 params=payload,
-                data=dumps({"logs": self.batch})
+                data=dumps({"logs": self.batch}),
+                timeout=self.timeout,
             )
         except (ConnectionError, ValueError):
             pass
@@ -41,5 +43,6 @@ class QWhaleLogsHandler(Handler):
         self.__upload()
 
     def close(self) -> None:
+        self.flush()
         super().close()
         self.executor.shutdown()
